@@ -34,3 +34,7 @@ class Addon(Model):
     @staticmethod
     def copy(params, env=None, headers=None):
         return request.send('post', request.uri_path("addons","copy"), params, env, headers)
+
+    @staticmethod
+    def unarchive(id, env=None, headers=None):
+        return request.send('post', request.uri_path("addons",id,"unarchive"), None, env, headers)
