@@ -14,11 +14,12 @@ class Transaction(Model):
       fields = ["txn_id", "txn_status", "txn_date", "txn_amount"]
       pass
 
-    fields = ["id", "customer_id", "subscription_id", "gateway_account_id", "payment_method", \
-    "reference_number", "gateway", "type", "date", "currency_code", "amount", "id_at_gateway", "status", \
-    "fraud_flag", "error_code", "error_text", "voided_at", "resource_version", "updated_at", "fraud_reason", \
-    "amount_unused", "masked_card_number", "reference_transaction_id", "refunded_txn_id", "reversal_transaction_id", \
-    "linked_invoices", "linked_credit_notes", "linked_refunds", "deleted"]
+    fields = ["id", "customer_id", "subscription_id", "gateway_account_id", "payment_source_id", \
+    "payment_method", "reference_number", "gateway", "type", "date", "settled_at", "currency_code", \
+    "amount", "id_at_gateway", "status", "fraud_flag", "error_code", "error_text", "voided_at", \
+    "resource_version", "updated_at", "fraud_reason", "amount_unused", "masked_card_number", "reference_transaction_id", \
+    "refunded_txn_id", "reversal_transaction_id", "linked_invoices", "linked_credit_notes", "linked_refunds", \
+    "deleted"]
 
 
     @staticmethod
