@@ -7,7 +7,7 @@ class UnbilledCharge(Model):
 
     fields = ["id", "customer_id", "subscription_id", "date_from", "date_to", "unit_amount", \
     "quantity", "amount", "currency_code", "discount_amount", "description", "entity_type", "entity_id", \
-    "is_voided", "voided_at"]
+    "is_voided", "voided_at", "deleted"]
 
 
     @staticmethod
