@@ -17,7 +17,7 @@ class Result(object):
     @property
     def customer(self):
         customer = self._get('customer', Customer,
-        {'billing_address' : Customer.BillingAddress, 'referral_urls' : Customer.ReferralUrl, 'contacts' : Customer.Contact, 'payment_method' : Customer.PaymentMethod});
+        {'billing_address' : Customer.BillingAddress, 'referral_urls' : Customer.ReferralUrl, 'contacts' : Customer.Contact, 'payment_method' : Customer.PaymentMethod, 'balances' : Customer.Balance});
         return customer;
 
     @property
@@ -36,6 +36,11 @@ class Result(object):
         card = self._get('card', Card);
         return card;
 
+    @property
+    def promotional_credit(self):
+        promotional_credit = self._get('promotional_credit', PromotionalCredit);
+        return promotional_credit;
+
     @property
     def invoice(self):
         invoice = self._get('invoice', Invoice,
@@ -102,6 +107,11 @@ class Result(object):
         coupon = self._get('coupon', Coupon);
         return coupon;
 
+    @property
+    def coupon_set(self):
+        coupon_set = self._get('coupon_set', CouponSet);
+        return coupon_set;
+
     @property
     def coupon_code(self):
         coupon_code = self._get('coupon_code', CouponCode);
